/* $Id: tst.c,v 1.1.1.1 2000/05/07 12:26:58 sverrehu Exp $ */
/*------------------------------------------------------------------------
 |  FILE            tst.c
 |
 |  DESCRIPTION     Tests the MD5 algorithm implemented in md5.c.
 |                  A rather simple test: Assumes arguments are filenames.
 |                  For each filename given, reads the file into a buffer,
 |                  and calculates the MD5 sum of its contents.  The output
 |                  format is the same as for GNU md5sum, to be able to
 |                  compare using diff.
 |
 |  WRITTEN BY      Sverre H. Huseby <sverrehu@online.no>
 +----------------------------------------------------------------------*/

#include <stdio.h>
#include <stdlib.h>

#include "md5.h"

/*-----------------------------------------------------------------------+
|  PUBLIC FUNCTIONS                                                      |
+-----------------------------------------------------------------------*/

int
main(int argc, char *argv[])
{
#define BUFFLEN 65536
    char          s[33];
    int           q, len, totLen;
    FILE          *f;
    unsigned char *buff;
    unsigned char *file;

    if ((buff = (unsigned char *) malloc(BUFFLEN)) == NULL) {
        fprintf(stderr, "out of memory\n");
        exit(1);
    }
    for (q = 1; q < argc; q++) {
        file = NULL;
        totLen = 0;
        if ((f = fopen(argv[q], "rb")) == NULL) {
            fprintf(stderr, "error opening %s\n", argv[q]);
            continue;
        }
        while ((len = fread(buff, 1, BUFFLEN, f)) > 0) {
            if (file == NULL)
                file = (unsigned char *) malloc(sizeof(unsigned char) * len);
            else
                file = (unsigned char *) realloc(file, sizeof(unsigned char)
                                             * (totLen + len));
            memcpy(file + totLen, buff, len);
            totLen += len;
        }
        fclose(f);
        if (!md5_hash(file, totLen, s)) {
            fprintf(stderr, "out of memory\n");
            exit(1);
        }
        free(file);
        printf("%s  %s\n", s, argv[q]);
    }
    return 0;
}
